// Estilos globales
import '@/styles/globals.css'

// Dependencias
import { ThemeProvider } from '@/components/theme-provider'
import ResponsiveContainer from '@/layout/ResponsiveContainer'
import LoadingProvider from '@/plugins/LoadingContext'
import I18nProvider from '@/plugins/i18nContext'
import presets from '@/utils/globalPresets'
import { Portal } from '@headlessui/react'
import Head from 'next/head'
import { ToastContainer } from 'react-toastify'

export default function App ({ Component, pageProps }) {
  return (
    <>
      <Head>
        <link rel="icon" href={presets.images.icon} type="image/x-icon" />
        <title>Orbis Template</title>
      </Head>

      <ThemeProvider
        attribute="class"
        defaultTheme="system"
        enableSystem
      >
        <I18nProvider locale={'es'} dict={''}>
          <LoadingProvider>
            <Portal>
              <ToastContainer
                {...presets.toaster}
                toastClassName={'rounded-lg bg-white text-black shadow-md dark:!bg-black dark:text-white'}
                style={{ zIndex: 99999 }}
              />
            </Portal>
            <ResponsiveContainer>
              <Component {...pageProps} />
            </ResponsiveContainer>
          </LoadingProvider>
        </I18nProvider>
      </ThemeProvider>
    </>
  )
}
